@@ -23,9 +23,11 @@
 
 #include <QWidget>
 
+#include <KUrl>
+
 #include <TelepathyQt4/AccountManager>
 
-
+class KPixmapSequenceOverlayPainter;
 namespace Ui {
     class MainWindow;
 }
@@ -38,19 +40,22 @@ class MainWindow : public QWidget
     Q_OBJECT
 
 public:
-    explicit MainWindow(QWidget *parent = 0);
+    explicit MainWindow(const KUrl &url, QWidget *parent = 0);
     ~MainWindow();
 
 private slots:
     void onAccountManagerReady();
     void onDialogAccepted();
-
+    void onPreviewLoaded(const KFileItem &item, const QPixmap &preview);
+    void onPreviewFailed(const KFileItem &item);
     void slotFileTransferFinished(Tp::PendingOperation *op);
 
 private:
     Ui::MainWindow *ui;
     AccountsModel *m_accountsModel;
     Tp::AccountManagerPtr m_accountManager;
+
+    KPixmapSequenceOverlayPainter *m_busyOverlay;
 };
 
 #endif // MAINWINDOW_H
